package Acme::Test::MetaCPAN::NoContributingDoc;
use 5.008001;
use strict;
use warnings;

our $VERSION = "0.01";



1;
__END__

=encoding utf-8

=head1 NAME

Acme::Test::MetaCPAN::NoContributingDoc - Test module for MetaCPAN C</contributing-to>

=head1 DESCRIPTION

Acme::Test::MetaCPAN::NoContributingDoc is a dummy test dist that B<does
not> contain a C<CONTRIBUTING> file, for testing C</contributing-to>
path placeholder text.

=head1 SEE ALSO

L<https://metacpan.org/contributing-to/Acme-Test-MetaCPAN-NoContributingDoc>

=head1 LICENSE

Copyright (C) Zak B. Elep.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

Zak B. Elep E<lt>zakame@zakame.netE<gt>

=cut

